==> haskell-utf8-string-1.0.2-254-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
key:                  utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  bd3bf5c1239a6eb261a26ab9cce4d070
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utf8-string
hs-libraries:         HSutf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utf8-string-1.0.2-255-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
key:                  utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  20a37cf7de80fc21e0638e0f50b55205
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utf8-string
hs-libraries:         HSutf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
